/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/cognito-identity/CognitoIdentity_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
namespace Utils {
namespace Json {
class JsonValue;
class JsonView;
}  // namespace Json
}  // namespace Utils
namespace CognitoIdentity {
namespace Model {

/**
 * <p>A description of the identity pool.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/cognito-identity-2014-06-30/IdentityPoolShortDescription">AWS
 * API Reference</a></p>
 */
class IdentityPoolShortDescription {
 public:
  AWS_COGNITOIDENTITY_API IdentityPoolShortDescription() = default;
  AWS_COGNITOIDENTITY_API IdentityPoolShortDescription(Aws::Utils::Json::JsonView jsonValue);
  AWS_COGNITOIDENTITY_API IdentityPoolShortDescription& operator=(Aws::Utils::Json::JsonView jsonValue);
  AWS_COGNITOIDENTITY_API Aws::Utils::Json::JsonValue Jsonize() const;

  ///@{
  /**
   * <p>An identity pool ID in the format REGION:GUID.</p>
   */
  inline const Aws::String& GetIdentityPoolId() const { return m_identityPoolId; }
  inline bool IdentityPoolIdHasBeenSet() const { return m_identityPoolIdHasBeenSet; }
  template <typename IdentityPoolIdT = Aws::String>
  void SetIdentityPoolId(IdentityPoolIdT&& value) {
    m_identityPoolIdHasBeenSet = true;
    m_identityPoolId = std::forward<IdentityPoolIdT>(value);
  }
  template <typename IdentityPoolIdT = Aws::String>
  IdentityPoolShortDescription& WithIdentityPoolId(IdentityPoolIdT&& value) {
    SetIdentityPoolId(std::forward<IdentityPoolIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>A string that you provide.</p>
   */
  inline const Aws::String& GetIdentityPoolName() const { return m_identityPoolName; }
  inline bool IdentityPoolNameHasBeenSet() const { return m_identityPoolNameHasBeenSet; }
  template <typename IdentityPoolNameT = Aws::String>
  void SetIdentityPoolName(IdentityPoolNameT&& value) {
    m_identityPoolNameHasBeenSet = true;
    m_identityPoolName = std::forward<IdentityPoolNameT>(value);
  }
  template <typename IdentityPoolNameT = Aws::String>
  IdentityPoolShortDescription& WithIdentityPoolName(IdentityPoolNameT&& value) {
    SetIdentityPoolName(std::forward<IdentityPoolNameT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_identityPoolId;

  Aws::String m_identityPoolName;
  bool m_identityPoolIdHasBeenSet = false;
  bool m_identityPoolNameHasBeenSet = false;
};

}  // namespace Model
}  // namespace CognitoIdentity
}  // namespace Aws
