/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/http/HttpResponse.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/iam/IAM_EXPORTS.h>
#include <aws/iam/model/FeatureType.h>
#include <aws/iam/model/ResponseMetadata.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Xml {
class XmlDocument;
}  // namespace Xml
}  // namespace Utils
namespace IAM {
namespace Model {
class DisableOrganizationsRootSessionsResult {
 public:
  AWS_IAM_API DisableOrganizationsRootSessionsResult() = default;
  AWS_IAM_API DisableOrganizationsRootSessionsResult(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);
  AWS_IAM_API DisableOrganizationsRootSessionsResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);

  ///@{
  /**
   * <p>The unique identifier (ID) of an organization.</p>
   */
  inline const Aws::String& GetOrganizationId() const { return m_organizationId; }
  template <typename OrganizationIdT = Aws::String>
  void SetOrganizationId(OrganizationIdT&& value) {
    m_organizationIdHasBeenSet = true;
    m_organizationId = std::forward<OrganizationIdT>(value);
  }
  template <typename OrganizationIdT = Aws::String>
  DisableOrganizationsRootSessionsResult& WithOrganizationId(OrganizationIdT&& value) {
    SetOrganizationId(std::forward<OrganizationIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The features you have enabled for centralized root access of member accounts
   * in your organization.</p>
   */
  inline const Aws::Vector<FeatureType>& GetEnabledFeatures() const { return m_enabledFeatures; }
  template <typename EnabledFeaturesT = Aws::Vector<FeatureType>>
  void SetEnabledFeatures(EnabledFeaturesT&& value) {
    m_enabledFeaturesHasBeenSet = true;
    m_enabledFeatures = std::forward<EnabledFeaturesT>(value);
  }
  template <typename EnabledFeaturesT = Aws::Vector<FeatureType>>
  DisableOrganizationsRootSessionsResult& WithEnabledFeatures(EnabledFeaturesT&& value) {
    SetEnabledFeatures(std::forward<EnabledFeaturesT>(value));
    return *this;
  }
  inline DisableOrganizationsRootSessionsResult& AddEnabledFeatures(FeatureType value) {
    m_enabledFeaturesHasBeenSet = true;
    m_enabledFeatures.push_back(value);
    return *this;
  }
  ///@}

  ///@{

  inline const ResponseMetadata& GetResponseMetadata() const { return m_responseMetadata; }
  template <typename ResponseMetadataT = ResponseMetadata>
  void SetResponseMetadata(ResponseMetadataT&& value) {
    m_responseMetadataHasBeenSet = true;
    m_responseMetadata = std::forward<ResponseMetadataT>(value);
  }
  template <typename ResponseMetadataT = ResponseMetadata>
  DisableOrganizationsRootSessionsResult& WithResponseMetadata(ResponseMetadataT&& value) {
    SetResponseMetadata(std::forward<ResponseMetadataT>(value));
    return *this;
  }
  ///@}
  inline Aws::Http::HttpResponseCode GetHttpResponseCode() const { return m_HttpResponseCode; }

 private:
  Aws::String m_organizationId;

  Aws::Vector<FeatureType> m_enabledFeatures;

  ResponseMetadata m_responseMetadata;
  Aws::Http::HttpResponseCode m_HttpResponseCode;
  bool m_organizationIdHasBeenSet = false;
  bool m_enabledFeaturesHasBeenSet = false;
  bool m_responseMetadataHasBeenSet = false;
};

}  // namespace Model
}  // namespace IAM
}  // namespace Aws
